@@ -36,14 +36,17 @@ class CommercetoolsError(Exception):
     @property
     def codes(self) -> typing.List[str]:
         try:
-            return [e.code for e in self.response.errors]
+            if self.response.errors is not None:
+                return [e.code for e in self.response.errors]
+            else:
+                return []
         except AttributeError:
             return []
 
     @property
     def code(self) -> str:
         """Convenience property to easily get the error code.
-        
+
         Returns the code of the first error, just as
         'message' is always the message of the first error.
         """
