@@ -1,6 +1,7 @@
 from typing import List
 
-from commercetools import schemas, types
+from commercetools import types
+from commercetools._schemas._project import ProjectSchema, ProjectUpdateSchema
 from commercetools.services import abstract
 
 __all__ = ["ProjectService"]
@@ -8,7 +9,7 @@ __all__ = ["ProjectService"]
 
 class ProjectService(abstract.AbstractService):
     def get(self) -> types.Order:
-        return self._client._get("", {}, schemas.ProjectSchema)
+        return self._client._get("", {}, ProjectSchema)
 
     def update(
         self,
@@ -22,7 +23,7 @@ class ProjectService(abstract.AbstractService):
             endpoint="",
             params={},
             data_object=update_action,
-            request_schema_cls=schemas.ProjectUpdateSchema,
-            response_schema_cls=schemas.ProjectSchema,
+            request_schema_cls=ProjectUpdateSchema,
+            response_schema_cls=ProjectSchema,
             force_update=force_update,
         )
