@@ -2,12 +2,19 @@ import datetime
 import uuid
 from typing import Optional
 
-from commercetools import schemas, types
+from commercetools import types
+from commercetools._schemas._customer import (
+    CustomerDraftSchema,
+    CustomerPagedQueryResponseSchema,
+    CustomerSchema,
+    CustomerUpdateSchema,
+)
 from commercetools.testing import abstract, utils
+from commercetools.testing.utils import create_commercetools_response
 
 
 class CustomerModel(abstract.BaseModel):
-    _resource_schema = schemas.CustomerSchema
+    _resource_schema = CustomerSchema
     _primary_type_name = "customer"
     _unique_values = ["key"]
 
@@ -15,12 +22,13 @@ class CustomerModel(abstract.BaseModel):
         self, draft: types.CustomerDraft, id: Optional[str] = None
     ) -> types.Customer:
         object_id = uuid.UUID(id) if id is not None else uuid.uuid4()
+        now = datetime.datetime.now(datetime.timezone.utc)
 
         return types.Customer(
             id=str(object_id),
             version=1,
-            created_at=datetime.datetime.now(datetime.timezone.utc),
-            last_modified_at=None,
+            created_at=now,
+            last_modified_at=now,
             customer_number=draft.customer_number,
             email=draft.email,
             password=draft.password,
@@ -65,9 +73,9 @@ class CustomerModel(abstract.BaseModel):
 class CustomerBackend(abstract.ServiceBackend):
     service_path = "customers"
     model_class = CustomerModel
-    _schema_draft = schemas.CustomerDraftSchema
-    _schema_update = schemas.CustomerUpdateSchema
-    _schema_query_response = schemas.CustomerPagedQueryResponseSchema
+    _schema_draft = CustomerDraftSchema
+    _schema_update = CustomerUpdateSchema
+    _schema_query_response = CustomerPagedQueryResponseSchema
 
     def urls(self):
         return [
@@ -80,3 +88,13 @@ class CustomerBackend(abstract.ServiceBackend):
             ("^(?P<id>[^/]+)$", "POST", self.update_by_id),
             ("^(?P<id>[^/]+)$", "DELETE", self.delete_by_id),
         ]
+
+    def create(self, request):
+        obj = self._schema_draft().loads(request.body)
+        data = self.model.add(obj)
+
+        # Convert to CustomerSignInResult
+        data = {"customer": data, "cart": None}
+
+        expanded_data = self._expand(request, data)
+        return create_commercetools_response(request, json=expanded_data)
